# datamanipy

## What is it?

**datamanipy** is a Python package that provides tools to help you manipulating data.

## Where to get it?

The source code is currently hosted on [GitHub](https://github.com/alplepot/datamanipy).
Distribution files are available on PyPI.

```sh
# install datamanipy from PyPI
pip install datamanipy
```
## Dependencies

- [sqlalchemy](https://docs.sqlalchemy.org/en/14/)
- [pandas](https://pandas.pydata.org/)
- [datetime](https://docs.python.org/3/library/datetime.html)
- [keyring](https://keyring.readthedocs.io)
- [pyreadstat](https://pyreadstat.readthedocs.io)

## Contributing to art

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.
